@@ -20,7 +20,7 @@ from jinja2 import __version__ as jinja2_version
 import jinjafx, os, io, sys, socket, signal, threading, yaml, json, base64, time, datetime
 import re, argparse, zipfile, hashlib, traceback, glob, hmac, uuid, struct, binascii, gzip, requests
 
-__version__ = '22.1.7'
+__version__ = '22.2.2'
 
 try:
   from ansible.constants import DEFAULT_VAULT_ID_MATCH
@@ -138,7 +138,7 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
       r = [ 'text/plain', 200, 'OK\r\n'.encode('utf-8'), sys._getframe().f_lineno ]
 
     elif not api_only:
-      if fpath == '/':
+      if fpath == '/' or re.search(r'^/dt/[A-Za-z0-9_-]{1,24}$', fpath):
         fpath = '/index.html'
 
       if re.search(r'^/get_dt/[A-Za-z0-9_-]{1,24}$', fpath):
@@ -242,7 +242,6 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
         head = True
         r = [ None, 304, None, sys._getframe().f_lineno ]
 
-#    self.lnumber = r[3]
     self.send_response(r[1])
 
     if r[1] != 304:
@@ -272,7 +271,6 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
 
 
   def do_OPTIONS(self):
-#    self.lnumber = sys._getframe().f_lineno
     self.send_response(204)
     self.send_header('Allow', 'OPTIONS, HEAD, GET, POST')
     self.end_headers()
@@ -294,7 +292,6 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
         postdata = self.rfile.read(int(self.headers['Content-Length']))
         self.length = len(postdata)
 
-      # if (len(postdata) < (512 * 1024)) or (fpath == '/download'):
         if fpath == '/jinjafx':
           if self.headers['Content-Type'] == 'application/json':
             try:
@@ -304,8 +301,8 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                 postdata = gzip.decompress(postdata)
 
               dt = json.loads(postdata.decode('utf-8'))
-              template = base64.b64decode(dt['template']) if 'template' in dt and len(dt['template'].strip()) > 0 else ''
-              data = base64.b64decode(dt['data']) if 'data' in dt and len(dt['data'].strip()) > 0 else ''
+              template = base64.b64decode(dt['template']) if 'template' in dt and len(dt['template'].strip()) > 0 else b''
+              data = base64.b64decode(dt['data']) if 'data' in dt and len(dt['data'].strip()) > 0 else b''
   
               if 'vars' in dt and len(dt['vars'].strip()) > 0:
                 gyaml = base64.b64decode(dt['vars'])
@@ -326,7 +323,7 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                   gvars.update(y)
   
               st = round(time.time() * 1000)
-              outputs = jinjafx.JinjaFx().jinjafx(template, data, gvars, 'Output')
+              outputs = jinjafx.JinjaFx().jinjafx(template.decode('utf-8'), data.decode('utf-8'), gvars, 'Output')
               ocount = 0
   
               jsr = {
@@ -394,7 +391,6 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
 
                 z.close()
 
-#                self.lnumber = sys._getframe().f_lineno
                 self.send_response(200)
                 self.send_header('Content-Type', 'application/zip')
                 self.send_header('Content-Length', str(len(zfile.getvalue())))
@@ -515,7 +511,7 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                         raise Exception("invalid link format")
 
                     else:
-                      dt_link = self.encode_link(hashlib.sha256((str(uuid.uuid1()) + ':' + dt_yml).encode('utf-8')).digest()[:12])
+                      dt_link = self.encode_link(hashlib.sha256((str(uuid.uuid1()) + ':' + dt_yml).encode('utf-8')).digest()[:6])
 
                     dt_filename = 'jfx_' + dt_link + '.yml'
 
@@ -635,7 +631,6 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
     else:
       r = [ 'text/plain', 400, '400 Bad Request\r\n', sys._getframe().f_lineno ]
 
-#    self.lnumber = r[3]
     self.send_response(r[1])
 
     r[2] = r[2].encode('utf-8')
